[![PyPi version](https://badgen.net/pypi/v/wolf-cli)](https://pypi.com/project/wolf-cli)

# **Wolf**
## A CLI tool to assist and make easy repetitive tasks such as downloading images and URLs unshortening

### Built with:
- [Poetry](https://python-poetry.org/)
- [Typer](https://typer.tiangolo.com/)
---
This Project uses code adapted from: [Kevin Tewouda](https://lewoudar.medium.com/click-a-beautiful-python-library-to-write-cli-applications-9c8154847066)
